# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from influxdb_client.service._base_service import _BaseService


class BucketSchemasService(_BaseService):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):  # noqa: E501,D401,D403
        """BucketSchemasService - a operation defined in OpenAPI."""
        super().__init__(api_client)

    def create_measurement_schema(self, bucket_id, measurement_schema_create_request, **kwargs):  # noqa: E501,D401,D403
        """Create a measurement schema for a bucket.

        Creates an _explict_ measurement [schema](https://docs.influxdata.com/influxdb/cloud/reference/glossary/#schema) for a bucket.  _Explicit_ schemas are used to enforce column names, tags, fields, and data types for your data.  By default, buckets have an _implicit_ schema-type (`"schemaType": "implicit"`) that conforms to your data.  Use this endpoint to create schemas that prevent non-conforming write requests.  #### Limitations  - Buckets must be created with the "explict" `schemaType` in order to use schemas.  #### Related guides  - [Manage bucket schemas](https://docs.influxdata.com/influxdb/cloud/organizations/buckets/bucket-schema/). - [Create a bucket with an explicit schema](https://docs.influxdata.com/influxdb/cloud/organizations/buckets/create-bucket/#create-a-bucket-with-an-explicit-schema)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_measurement_schema(bucket_id, measurement_schema_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bucket_id: A bucket ID. Adds a schema for the specified bucket. (required)
        :param MeasurementSchemaCreateRequest measurement_schema_create_request: (required)
        :param str org: An organization name. Specifies the organization that owns the schema.
        :param str org_id: An organization ID. Specifies the organization that owns the schema.
        :return: MeasurementSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_measurement_schema_with_http_info(bucket_id, measurement_schema_create_request, **kwargs)  # noqa: E501
        else:
            (data) = self.create_measurement_schema_with_http_info(bucket_id, measurement_schema_create_request, **kwargs)  # noqa: E501
            return data

    def create_measurement_schema_with_http_info(self, bucket_id, measurement_schema_create_request, **kwargs):  # noqa: E501,D401,D403
        """Create a measurement schema for a bucket.

        Creates an _explict_ measurement [schema](https://docs.influxdata.com/influxdb/cloud/reference/glossary/#schema) for a bucket.  _Explicit_ schemas are used to enforce column names, tags, fields, and data types for your data.  By default, buckets have an _implicit_ schema-type (`"schemaType": "implicit"`) that conforms to your data.  Use this endpoint to create schemas that prevent non-conforming write requests.  #### Limitations  - Buckets must be created with the "explict" `schemaType` in order to use schemas.  #### Related guides  - [Manage bucket schemas](https://docs.influxdata.com/influxdb/cloud/organizations/buckets/bucket-schema/). - [Create a bucket with an explicit schema](https://docs.influxdata.com/influxdb/cloud/organizations/buckets/create-bucket/#create-a-bucket-with-an-explicit-schema)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_measurement_schema_with_http_info(bucket_id, measurement_schema_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bucket_id: A bucket ID. Adds a schema for the specified bucket. (required)
        :param MeasurementSchemaCreateRequest measurement_schema_create_request: (required)
        :param str org: An organization name. Specifies the organization that owns the schema.
        :param str org_id: An organization ID. Specifies the organization that owns the schema.
        :return: MeasurementSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not self._is_cloud_instance():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('BucketSchemasService',
                                           'https://docs.influxdata.com/influxdb/cloud/organizations/buckets/bucket-schema/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._create_measurement_schema_prepare(bucket_id, measurement_schema_create_request, **kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/buckets/{bucketID}/schema/measurements', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='MeasurementSchema',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def create_measurement_schema_async(self, bucket_id, measurement_schema_create_request, **kwargs):  # noqa: E501,D401,D403
        """Create a measurement schema for a bucket.

        Creates an _explict_ measurement [schema](https://docs.influxdata.com/influxdb/cloud/reference/glossary/#schema) for a bucket.  _Explicit_ schemas are used to enforce column names, tags, fields, and data types for your data.  By default, buckets have an _implicit_ schema-type (`"schemaType": "implicit"`) that conforms to your data.  Use this endpoint to create schemas that prevent non-conforming write requests.  #### Limitations  - Buckets must be created with the "explict" `schemaType` in order to use schemas.  #### Related guides  - [Manage bucket schemas](https://docs.influxdata.com/influxdb/cloud/organizations/buckets/bucket-schema/). - [Create a bucket with an explicit schema](https://docs.influxdata.com/influxdb/cloud/organizations/buckets/create-bucket/#create-a-bucket-with-an-explicit-schema)
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str bucket_id: A bucket ID. Adds a schema for the specified bucket. (required)
        :param MeasurementSchemaCreateRequest measurement_schema_create_request: (required)
        :param str org: An organization name. Specifies the organization that owns the schema.
        :param str org_id: An organization ID. Specifies the organization that owns the schema.
        :return: MeasurementSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not await self._is_cloud_instance_async():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('BucketSchemasService',
                                           'https://docs.influxdata.com/influxdb/cloud/organizations/buckets/bucket-schema/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._create_measurement_schema_prepare(bucket_id, measurement_schema_create_request, **kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/buckets/{bucketID}/schema/measurements', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='MeasurementSchema',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _create_measurement_schema_prepare(self, bucket_id, measurement_schema_create_request, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['bucket_id', 'measurement_schema_create_request', 'org', 'org_id']  # noqa: E501
        self._check_operation_params('create_measurement_schema', all_params, local_var_params)
        # verify the required parameter 'bucket_id' is set
        if ('bucket_id' not in local_var_params or
                local_var_params['bucket_id'] is None):
            raise ValueError("Missing the required parameter `bucket_id` when calling `create_measurement_schema`")  # noqa: E501
        # verify the required parameter 'measurement_schema_create_request' is set
        if ('measurement_schema_create_request' not in local_var_params or
                local_var_params['measurement_schema_create_request'] is None):
            raise ValueError("Missing the required parameter `measurement_schema_create_request` when calling `create_measurement_schema`")  # noqa: E501

        path_params = {}
        if 'bucket_id' in local_var_params:
            path_params['bucketID'] = local_var_params['bucket_id']  # noqa: E501

        query_params = []
        if 'org' in local_var_params:
            query_params.append(('org', local_var_params['org']))  # noqa: E501
        if 'org_id' in local_var_params:
            query_params.append(('orgID', local_var_params['org_id']))  # noqa: E501

        header_params = {}

        body_params = None
        if 'measurement_schema_create_request' in local_var_params:
            body_params = local_var_params['measurement_schema_create_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def get_measurement_schema(self, bucket_id, measurement_id, **kwargs):  # noqa: E501,D401,D403
        """Retrieve a measurement schema.

        Retrieves an explicit measurement [schema](https://docs.influxdata.com/influxdb/cloud/reference/glossary/#schema).
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_measurement_schema(bucket_id, measurement_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bucket_id: A bucket ID. Retrieves schemas for the specified bucket. (required)
        :param str measurement_id: The measurement schema ID. Specifies the measurement schema to retrieve. (required)
        :param str org: Organization name. Specifies the organization that owns the schema.
        :param str org_id: Organization ID. Specifies the organization that owns the schema.
        :return: MeasurementSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_measurement_schema_with_http_info(bucket_id, measurement_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_measurement_schema_with_http_info(bucket_id, measurement_id, **kwargs)  # noqa: E501
            return data

    def get_measurement_schema_with_http_info(self, bucket_id, measurement_id, **kwargs):  # noqa: E501,D401,D403
        """Retrieve a measurement schema.

        Retrieves an explicit measurement [schema](https://docs.influxdata.com/influxdb/cloud/reference/glossary/#schema).
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_measurement_schema_with_http_info(bucket_id, measurement_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bucket_id: A bucket ID. Retrieves schemas for the specified bucket. (required)
        :param str measurement_id: The measurement schema ID. Specifies the measurement schema to retrieve. (required)
        :param str org: Organization name. Specifies the organization that owns the schema.
        :param str org_id: Organization ID. Specifies the organization that owns the schema.
        :return: MeasurementSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not self._is_cloud_instance():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('BucketSchemasService',
                                           'https://docs.influxdata.com/influxdb/cloud/organizations/buckets/bucket-schema/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_measurement_schema_prepare(bucket_id, measurement_id, **kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/buckets/{bucketID}/schema/measurements/{measurementID}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='MeasurementSchema',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def get_measurement_schema_async(self, bucket_id, measurement_id, **kwargs):  # noqa: E501,D401,D403
        """Retrieve a measurement schema.

        Retrieves an explicit measurement [schema](https://docs.influxdata.com/influxdb/cloud/reference/glossary/#schema).
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str bucket_id: A bucket ID. Retrieves schemas for the specified bucket. (required)
        :param str measurement_id: The measurement schema ID. Specifies the measurement schema to retrieve. (required)
        :param str org: Organization name. Specifies the organization that owns the schema.
        :param str org_id: Organization ID. Specifies the organization that owns the schema.
        :return: MeasurementSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not await self._is_cloud_instance_async():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('BucketSchemasService',
                                           'https://docs.influxdata.com/influxdb/cloud/organizations/buckets/bucket-schema/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_measurement_schema_prepare(bucket_id, measurement_id, **kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/buckets/{bucketID}/schema/measurements/{measurementID}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='MeasurementSchema',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _get_measurement_schema_prepare(self, bucket_id, measurement_id, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['bucket_id', 'measurement_id', 'org', 'org_id']  # noqa: E501
        self._check_operation_params('get_measurement_schema', all_params, local_var_params)
        # verify the required parameter 'bucket_id' is set
        if ('bucket_id' not in local_var_params or
                local_var_params['bucket_id'] is None):
            raise ValueError("Missing the required parameter `bucket_id` when calling `get_measurement_schema`")  # noqa: E501
        # verify the required parameter 'measurement_id' is set
        if ('measurement_id' not in local_var_params or
                local_var_params['measurement_id'] is None):
            raise ValueError("Missing the required parameter `measurement_id` when calling `get_measurement_schema`")  # noqa: E501

        path_params = {}
        if 'bucket_id' in local_var_params:
            path_params['bucketID'] = local_var_params['bucket_id']  # noqa: E501
        if 'measurement_id' in local_var_params:
            path_params['measurementID'] = local_var_params['measurement_id']  # noqa: E501

        query_params = []
        if 'org' in local_var_params:
            query_params.append(('org', local_var_params['org']))  # noqa: E501
        if 'org_id' in local_var_params:
            query_params.append(('orgID', local_var_params['org_id']))  # noqa: E501

        header_params = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def get_measurement_schemas(self, bucket_id, **kwargs):  # noqa: E501,D401,D403
        """List measurement schemas of a bucket.

        Lists _explicit_ [schemas](https://docs.influxdata.com/influxdb/cloud/reference/glossary/#schema) (`"schemaType": "explicit"`) for a bucket.  _Explicit_ schemas are used to enforce column names, tags, fields, and data types for your data.  By default, buckets have an _implicit_ schema-type (`"schemaType": "implicit"`) that conforms to your data.  #### Related guides  - [Using bucket schemas](https://www.influxdata.com/blog/new-bucket-schema-option-protect-from-unwanted-schema-changes/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_measurement_schemas(bucket_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bucket_id: A bucket ID. Lists measurement schemas for the specified bucket. (required)
        :param str org: An organization name. Specifies the organization that owns the schema.
        :param str org_id: An organization ID. Specifies the organization that owns the schema.
        :param str name: A measurement name. Only returns measurement schemas with the specified name.
        :return: MeasurementSchemaList
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_measurement_schemas_with_http_info(bucket_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_measurement_schemas_with_http_info(bucket_id, **kwargs)  # noqa: E501
            return data

    def get_measurement_schemas_with_http_info(self, bucket_id, **kwargs):  # noqa: E501,D401,D403
        """List measurement schemas of a bucket.

        Lists _explicit_ [schemas](https://docs.influxdata.com/influxdb/cloud/reference/glossary/#schema) (`"schemaType": "explicit"`) for a bucket.  _Explicit_ schemas are used to enforce column names, tags, fields, and data types for your data.  By default, buckets have an _implicit_ schema-type (`"schemaType": "implicit"`) that conforms to your data.  #### Related guides  - [Using bucket schemas](https://www.influxdata.com/blog/new-bucket-schema-option-protect-from-unwanted-schema-changes/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_measurement_schemas_with_http_info(bucket_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bucket_id: A bucket ID. Lists measurement schemas for the specified bucket. (required)
        :param str org: An organization name. Specifies the organization that owns the schema.
        :param str org_id: An organization ID. Specifies the organization that owns the schema.
        :param str name: A measurement name. Only returns measurement schemas with the specified name.
        :return: MeasurementSchemaList
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not self._is_cloud_instance():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('BucketSchemasService',
                                           'https://docs.influxdata.com/influxdb/cloud/organizations/buckets/bucket-schema/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_measurement_schemas_prepare(bucket_id, **kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/buckets/{bucketID}/schema/measurements', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='MeasurementSchemaList',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def get_measurement_schemas_async(self, bucket_id, **kwargs):  # noqa: E501,D401,D403
        """List measurement schemas of a bucket.

        Lists _explicit_ [schemas](https://docs.influxdata.com/influxdb/cloud/reference/glossary/#schema) (`"schemaType": "explicit"`) for a bucket.  _Explicit_ schemas are used to enforce column names, tags, fields, and data types for your data.  By default, buckets have an _implicit_ schema-type (`"schemaType": "implicit"`) that conforms to your data.  #### Related guides  - [Using bucket schemas](https://www.influxdata.com/blog/new-bucket-schema-option-protect-from-unwanted-schema-changes/)
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str bucket_id: A bucket ID. Lists measurement schemas for the specified bucket. (required)
        :param str org: An organization name. Specifies the organization that owns the schema.
        :param str org_id: An organization ID. Specifies the organization that owns the schema.
        :param str name: A measurement name. Only returns measurement schemas with the specified name.
        :return: MeasurementSchemaList
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not await self._is_cloud_instance_async():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('BucketSchemasService',
                                           'https://docs.influxdata.com/influxdb/cloud/organizations/buckets/bucket-schema/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_measurement_schemas_prepare(bucket_id, **kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/buckets/{bucketID}/schema/measurements', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='MeasurementSchemaList',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _get_measurement_schemas_prepare(self, bucket_id, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['bucket_id', 'org', 'org_id', 'name']  # noqa: E501
        self._check_operation_params('get_measurement_schemas', all_params, local_var_params)
        # verify the required parameter 'bucket_id' is set
        if ('bucket_id' not in local_var_params or
                local_var_params['bucket_id'] is None):
            raise ValueError("Missing the required parameter `bucket_id` when calling `get_measurement_schemas`")  # noqa: E501

        path_params = {}
        if 'bucket_id' in local_var_params:
            path_params['bucketID'] = local_var_params['bucket_id']  # noqa: E501

        query_params = []
        if 'org' in local_var_params:
            query_params.append(('org', local_var_params['org']))  # noqa: E501
        if 'org_id' in local_var_params:
            query_params.append(('orgID', local_var_params['org_id']))  # noqa: E501
        if 'name' in local_var_params:
            query_params.append(('name', local_var_params['name']))  # noqa: E501

        header_params = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def update_measurement_schema(self, bucket_id, measurement_id, measurement_schema_update_request, **kwargs):  # noqa: E501,D401,D403
        """Update a measurement schema.

        Updates a measurement [schema](https://docs.influxdata.com/influxdb/cloud/reference/glossary/#schema).  Use this endpoint to update the fields (`name`, `type`, and `dataType`) of a measurement schema.  #### Limitations  - You can't update the `name` of a measurement.  #### Related guides  - [Manage bucket schemas](https://docs.influxdata.com/influxdb/cloud/organizations/buckets/bucket-schema/). - [Using bucket schemas](https://www.influxdata.com/blog/new-bucket-schema-option-protect-from-unwanted-schema-changes/).
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_measurement_schema(bucket_id, measurement_id, measurement_schema_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bucket_id: A bucket ID. Specifies the bucket to retrieve schemas for. (required)
        :param str measurement_id: A measurement schema ID. Retrieves the specified measurement schema. (required)
        :param MeasurementSchemaUpdateRequest measurement_schema_update_request: (required)
        :param str org: An organization name. Specifies the organization that owns the schema.
        :param str org_id: An organization ID. Specifies the organization that owns the schema.
        :return: MeasurementSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_measurement_schema_with_http_info(bucket_id, measurement_id, measurement_schema_update_request, **kwargs)  # noqa: E501
        else:
            (data) = self.update_measurement_schema_with_http_info(bucket_id, measurement_id, measurement_schema_update_request, **kwargs)  # noqa: E501
            return data

    def update_measurement_schema_with_http_info(self, bucket_id, measurement_id, measurement_schema_update_request, **kwargs):  # noqa: E501,D401,D403
        """Update a measurement schema.

        Updates a measurement [schema](https://docs.influxdata.com/influxdb/cloud/reference/glossary/#schema).  Use this endpoint to update the fields (`name`, `type`, and `dataType`) of a measurement schema.  #### Limitations  - You can't update the `name` of a measurement.  #### Related guides  - [Manage bucket schemas](https://docs.influxdata.com/influxdb/cloud/organizations/buckets/bucket-schema/). - [Using bucket schemas](https://www.influxdata.com/blog/new-bucket-schema-option-protect-from-unwanted-schema-changes/).
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_measurement_schema_with_http_info(bucket_id, measurement_id, measurement_schema_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bucket_id: A bucket ID. Specifies the bucket to retrieve schemas for. (required)
        :param str measurement_id: A measurement schema ID. Retrieves the specified measurement schema. (required)
        :param MeasurementSchemaUpdateRequest measurement_schema_update_request: (required)
        :param str org: An organization name. Specifies the organization that owns the schema.
        :param str org_id: An organization ID. Specifies the organization that owns the schema.
        :return: MeasurementSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not self._is_cloud_instance():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('BucketSchemasService',
                                           'https://docs.influxdata.com/influxdb/cloud/organizations/buckets/bucket-schema/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._update_measurement_schema_prepare(bucket_id, measurement_id, measurement_schema_update_request, **kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/buckets/{bucketID}/schema/measurements/{measurementID}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='MeasurementSchema',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def update_measurement_schema_async(self, bucket_id, measurement_id, measurement_schema_update_request, **kwargs):  # noqa: E501,D401,D403
        """Update a measurement schema.

        Updates a measurement [schema](https://docs.influxdata.com/influxdb/cloud/reference/glossary/#schema).  Use this endpoint to update the fields (`name`, `type`, and `dataType`) of a measurement schema.  #### Limitations  - You can't update the `name` of a measurement.  #### Related guides  - [Manage bucket schemas](https://docs.influxdata.com/influxdb/cloud/organizations/buckets/bucket-schema/). - [Using bucket schemas](https://www.influxdata.com/blog/new-bucket-schema-option-protect-from-unwanted-schema-changes/).
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str bucket_id: A bucket ID. Specifies the bucket to retrieve schemas for. (required)
        :param str measurement_id: A measurement schema ID. Retrieves the specified measurement schema. (required)
        :param MeasurementSchemaUpdateRequest measurement_schema_update_request: (required)
        :param str org: An organization name. Specifies the organization that owns the schema.
        :param str org_id: An organization ID. Specifies the organization that owns the schema.
        :return: MeasurementSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not await self._is_cloud_instance_async():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('BucketSchemasService',
                                           'https://docs.influxdata.com/influxdb/cloud/organizations/buckets/bucket-schema/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._update_measurement_schema_prepare(bucket_id, measurement_id, measurement_schema_update_request, **kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/buckets/{bucketID}/schema/measurements/{measurementID}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='MeasurementSchema',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _update_measurement_schema_prepare(self, bucket_id, measurement_id, measurement_schema_update_request, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['bucket_id', 'measurement_id', 'measurement_schema_update_request', 'org', 'org_id']  # noqa: E501
        self._check_operation_params('update_measurement_schema', all_params, local_var_params)
        # verify the required parameter 'bucket_id' is set
        if ('bucket_id' not in local_var_params or
                local_var_params['bucket_id'] is None):
            raise ValueError("Missing the required parameter `bucket_id` when calling `update_measurement_schema`")  # noqa: E501
        # verify the required parameter 'measurement_id' is set
        if ('measurement_id' not in local_var_params or
                local_var_params['measurement_id'] is None):
            raise ValueError("Missing the required parameter `measurement_id` when calling `update_measurement_schema`")  # noqa: E501
        # verify the required parameter 'measurement_schema_update_request' is set
        if ('measurement_schema_update_request' not in local_var_params or
                local_var_params['measurement_schema_update_request'] is None):
            raise ValueError("Missing the required parameter `measurement_schema_update_request` when calling `update_measurement_schema`")  # noqa: E501

        path_params = {}
        if 'bucket_id' in local_var_params:
            path_params['bucketID'] = local_var_params['bucket_id']  # noqa: E501
        if 'measurement_id' in local_var_params:
            path_params['measurementID'] = local_var_params['measurement_id']  # noqa: E501

        query_params = []
        if 'org' in local_var_params:
            query_params.append(('org', local_var_params['org']))  # noqa: E501
        if 'org_id' in local_var_params:
            query_params.append(('orgID', local_var_params['org_id']))  # noqa: E501

        header_params = {}

        body_params = None
        if 'measurement_schema_update_request' in local_var_params:
            body_params = local_var_params['measurement_schema_update_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

from influxdb_client.domain.threshold_base import ThresholdBase


class RangeThreshold(ThresholdBase):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'min': 'float',
        'max': 'float',
        'within': 'bool',
        'level': 'CheckStatusLevel',
        'all_values': 'bool'
    }

    attribute_map = {
        'type': 'type',
        'min': 'min',
        'max': 'max',
        'within': 'within',
        'level': 'level',
        'all_values': 'allValues'
    }

    def __init__(self, type="range", min=None, max=None, within=None, level=None, all_values=None):  # noqa: E501,D401,D403
        """RangeThreshold - a model defined in OpenAPI."""  # noqa: E501
        ThresholdBase.__init__(self, level=level, all_values=all_values)  # noqa: E501

        self._type = None
        self._min = None
        self._max = None
        self._within = None
        self.discriminator = None

        self.type = type
        self.min = min
        self.max = max
        self.within = within

    @property
    def type(self):
        """Get the type of this RangeThreshold.

        :return: The type of this RangeThreshold.
        :rtype: str
        """  # noqa: E501
        return self._type

    @type.setter
    def type(self, type):
        """Set the type of this RangeThreshold.

        :param type: The type of this RangeThreshold.
        :type: str
        """  # noqa: E501
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        self._type = type

    @property
    def min(self):
        """Get the min of this RangeThreshold.

        :return: The min of this RangeThreshold.
        :rtype: float
        """  # noqa: E501
        return self._min

    @min.setter
    def min(self, min):
        """Set the min of this RangeThreshold.

        :param min: The min of this RangeThreshold.
        :type: float
        """  # noqa: E501
        if min is None:
            raise ValueError("Invalid value for `min`, must not be `None`")  # noqa: E501
        self._min = min

    @property
    def max(self):
        """Get the max of this RangeThreshold.

        :return: The max of this RangeThreshold.
        :rtype: float
        """  # noqa: E501
        return self._max

    @max.setter
    def max(self, max):
        """Set the max of this RangeThreshold.

        :param max: The max of this RangeThreshold.
        :type: float
        """  # noqa: E501
        if max is None:
            raise ValueError("Invalid value for `max`, must not be `None`")  # noqa: E501
        self._max = max

    @property
    def within(self):
        """Get the within of this RangeThreshold.

        :return: The within of this RangeThreshold.
        :rtype: bool
        """  # noqa: E501
        return self._within

    @within.setter
    def within(self, within):
        """Set the within of this RangeThreshold.

        :param within: The within of this RangeThreshold.
        :type: bool
        """  # noqa: E501
        if within is None:
            raise ValueError("Invalid value for `within`, must not be `None`")  # noqa: E501
        self._within = within

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, RangeThreshold):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401


class RetentionPolicyManifest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'replica_n': 'int',
        'duration': 'int',
        'shard_group_duration': 'int',
        'shard_groups': 'list[ShardGroupManifest]',
        'subscriptions': 'list[SubscriptionManifest]'
    }

    attribute_map = {
        'name': 'name',
        'replica_n': 'replicaN',
        'duration': 'duration',
        'shard_group_duration': 'shardGroupDuration',
        'shard_groups': 'shardGroups',
        'subscriptions': 'subscriptions'
    }

    def __init__(self, name=None, replica_n=None, duration=None, shard_group_duration=None, shard_groups=None, subscriptions=None):  # noqa: E501,D401,D403
        """RetentionPolicyManifest - a model defined in OpenAPI."""  # noqa: E501
        self._name = None
        self._replica_n = None
        self._duration = None
        self._shard_group_duration = None
        self._shard_groups = None
        self._subscriptions = None
        self.discriminator = None

        self.name = name
        self.replica_n = replica_n
        self.duration = duration
        self.shard_group_duration = shard_group_duration
        self.shard_groups = shard_groups
        self.subscriptions = subscriptions

    @property
    def name(self):
        """Get the name of this RetentionPolicyManifest.

        :return: The name of this RetentionPolicyManifest.
        :rtype: str
        """  # noqa: E501
        return self._name

    @name.setter
    def name(self, name):
        """Set the name of this RetentionPolicyManifest.

        :param name: The name of this RetentionPolicyManifest.
        :type: str
        """  # noqa: E501
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        self._name = name

    @property
    def replica_n(self):
        """Get the replica_n of this RetentionPolicyManifest.

        :return: The replica_n of this RetentionPolicyManifest.
        :rtype: int
        """  # noqa: E501
        return self._replica_n

    @replica_n.setter
    def replica_n(self, replica_n):
        """Set the replica_n of this RetentionPolicyManifest.

        :param replica_n: The replica_n of this RetentionPolicyManifest.
        :type: int
        """  # noqa: E501
        if replica_n is None:
            raise ValueError("Invalid value for `replica_n`, must not be `None`")  # noqa: E501
        self._replica_n = replica_n

    @property
    def duration(self):
        """Get the duration of this RetentionPolicyManifest.

        :return: The duration of this RetentionPolicyManifest.
        :rtype: int
        """  # noqa: E501
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Set the duration of this RetentionPolicyManifest.

        :param duration: The duration of this RetentionPolicyManifest.
        :type: int
        """  # noqa: E501
        if duration is None:
            raise ValueError("Invalid value for `duration`, must not be `None`")  # noqa: E501
        self._duration = duration

    @property
    def shard_group_duration(self):
        """Get the shard_group_duration of this RetentionPolicyManifest.

        :return: The shard_group_duration of this RetentionPolicyManifest.
        :rtype: int
        """  # noqa: E501
        return self._shard_group_duration

    @shard_group_duration.setter
    def shard_group_duration(self, shard_group_duration):
        """Set the shard_group_duration of this RetentionPolicyManifest.

        :param shard_group_duration: The shard_group_duration of this RetentionPolicyManifest.
        :type: int
        """  # noqa: E501
        if shard_group_duration is None:
            raise ValueError("Invalid value for `shard_group_duration`, must not be `None`")  # noqa: E501
        self._shard_group_duration = shard_group_duration

    @property
    def shard_groups(self):
        """Get the shard_groups of this RetentionPolicyManifest.

        :return: The shard_groups of this RetentionPolicyManifest.
        :rtype: list[ShardGroupManifest]
        """  # noqa: E501
        return self._shard_groups

    @shard_groups.setter
    def shard_groups(self, shard_groups):
        """Set the shard_groups of this RetentionPolicyManifest.

        :param shard_groups: The shard_groups of this RetentionPolicyManifest.
        :type: list[ShardGroupManifest]
        """  # noqa: E501
        if shard_groups is None:
            raise ValueError("Invalid value for `shard_groups`, must not be `None`")  # noqa: E501
        self._shard_groups = shard_groups

    @property
    def subscriptions(self):
        """Get the subscriptions of this RetentionPolicyManifest.

        :return: The subscriptions of this RetentionPolicyManifest.
        :rtype: list[SubscriptionManifest]
        """  # noqa: E501
        return self._subscriptions

    @subscriptions.setter
    def subscriptions(self, subscriptions):
        """Set the subscriptions of this RetentionPolicyManifest.

        :param subscriptions: The subscriptions of this RetentionPolicyManifest.
        :type: list[SubscriptionManifest]
        """  # noqa: E501
        if subscriptions is None:
            raise ValueError("Invalid value for `subscriptions`, must not be `None`")  # noqa: E501
        self._subscriptions = subscriptions

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, RetentionPolicyManifest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401


class StaticLegend(object):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'colorize_rows': 'bool',
        'height_ratio': 'float',
        'show': 'bool',
        'opacity': 'float',
        'orientation_threshold': 'int',
        'value_axis': 'str',
        'width_ratio': 'float'
    }

    attribute_map = {
        'colorize_rows': 'colorizeRows',
        'height_ratio': 'heightRatio',
        'show': 'show',
        'opacity': 'opacity',
        'orientation_threshold': 'orientationThreshold',
        'value_axis': 'valueAxis',
        'width_ratio': 'widthRatio'
    }

    def __init__(self, colorize_rows=None, height_ratio=None, show=None, opacity=None, orientation_threshold=None, value_axis=None, width_ratio=None):  # noqa: E501,D401,D403
        """StaticLegend - a model defined in OpenAPI."""  # noqa: E501
        self._colorize_rows = None
        self._height_ratio = None
        self._show = None
        self._opacity = None
        self._orientation_threshold = None
        self._value_axis = None
        self._width_ratio = None
        self.discriminator = None

        if colorize_rows is not None:
            self.colorize_rows = colorize_rows
        if height_ratio is not None:
            self.height_ratio = height_ratio
        if show is not None:
            self.show = show
        if opacity is not None:
            self.opacity = opacity
        if orientation_threshold is not None:
            self.orientation_threshold = orientation_threshold
        if value_axis is not None:
            self.value_axis = value_axis
        if width_ratio is not None:
            self.width_ratio = width_ratio

    @property
    def colorize_rows(self):
        """Get the colorize_rows of this StaticLegend.

        :return: The colorize_rows of this StaticLegend.
        :rtype: bool
        """  # noqa: E501
        return self._colorize_rows

    @colorize_rows.setter
    def colorize_rows(self, colorize_rows):
        """Set the colorize_rows of this StaticLegend.

        :param colorize_rows: The colorize_rows of this StaticLegend.
        :type: bool
        """  # noqa: E501
        self._colorize_rows = colorize_rows

    @property
    def height_ratio(self):
        """Get the height_ratio of this StaticLegend.

        :return: The height_ratio of this StaticLegend.
        :rtype: float
        """  # noqa: E501
        return self._height_ratio

    @height_ratio.setter
    def height_ratio(self, height_ratio):
        """Set the height_ratio of this StaticLegend.

        :param height_ratio: The height_ratio of this StaticLegend.
        :type: float
        """  # noqa: E501
        self._height_ratio = height_ratio

    @property
    def show(self):
        """Get the show of this StaticLegend.

        :return: The show of this StaticLegend.
        :rtype: bool
        """  # noqa: E501
        return self._show

    @show.setter
    def show(self, show):
        """Set the show of this StaticLegend.

        :param show: The show of this StaticLegend.
        :type: bool
        """  # noqa: E501
        self._show = show

    @property
    def opacity(self):
        """Get the opacity of this StaticLegend.

        :return: The opacity of this StaticLegend.
        :rtype: float
        """  # noqa: E501
        return self._opacity

    @opacity.setter
    def opacity(self, opacity):
        """Set the opacity of this StaticLegend.

        :param opacity: The opacity of this StaticLegend.
        :type: float
        """  # noqa: E501
        self._opacity = opacity

    @property
    def orientation_threshold(self):
        """Get the orientation_threshold of this StaticLegend.

        :return: The orientation_threshold of this StaticLegend.
        :rtype: int
        """  # noqa: E501
        return self._orientation_threshold

    @orientation_threshold.setter
    def orientation_threshold(self, orientation_threshold):
        """Set the orientation_threshold of this StaticLegend.

        :param orientation_threshold: The orientation_threshold of this StaticLegend.
        :type: int
        """  # noqa: E501
        self._orientation_threshold = orientation_threshold

    @property
    def value_axis(self):
        """Get the value_axis of this StaticLegend.

        :return: The value_axis of this StaticLegend.
        :rtype: str
        """  # noqa: E501
        return self._value_axis

    @value_axis.setter
    def value_axis(self, value_axis):
        """Set the value_axis of this StaticLegend.

        :param value_axis: The value_axis of this StaticLegend.
        :type: str
        """  # noqa: E501
        self._value_axis = value_axis

    @property
    def width_ratio(self):
        """Get the width_ratio of this StaticLegend.

        :return: The width_ratio of this StaticLegend.
        :rtype: float
        """  # noqa: E501
        return self._width_ratio

    @width_ratio.setter
    def width_ratio(self, width_ratio):
        """Set the width_ratio of this StaticLegend.

        :param width_ratio: The width_ratio of this StaticLegend.
        :type: float
        """  # noqa: E501
        self._width_ratio = width_ratio

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, StaticLegend):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401


class ShardGroupManifest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'start_time': 'datetime',
        'end_time': 'datetime',
        'deleted_at': 'datetime',
        'truncated_at': 'datetime',
        'shards': 'list[ShardManifest]'
    }

    attribute_map = {
        'id': 'id',
        'start_time': 'startTime',
        'end_time': 'endTime',
        'deleted_at': 'deletedAt',
        'truncated_at': 'truncatedAt',
        'shards': 'shards'
    }

    def __init__(self, id=None, start_time=None, end_time=None, deleted_at=None, truncated_at=None, shards=None):  # noqa: E501,D401,D403
        """ShardGroupManifest - a model defined in OpenAPI."""  # noqa: E501
        self._id = None
        self._start_time = None
        self._end_time = None
        self._deleted_at = None
        self._truncated_at = None
        self._shards = None
        self.discriminator = None

        self.id = id
        self.start_time = start_time
        self.end_time = end_time
        if deleted_at is not None:
            self.deleted_at = deleted_at
        if truncated_at is not None:
            self.truncated_at = truncated_at
        self.shards = shards

    @property
    def id(self):
        """Get the id of this ShardGroupManifest.

        :return: The id of this ShardGroupManifest.
        :rtype: int
        """  # noqa: E501
        return self._id

    @id.setter
    def id(self, id):
        """Set the id of this ShardGroupManifest.

        :param id: The id of this ShardGroupManifest.
        :type: int
        """  # noqa: E501
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501
        self._id = id

    @property
    def start_time(self):
        """Get the start_time of this ShardGroupManifest.

        :return: The start_time of this ShardGroupManifest.
        :rtype: datetime
        """  # noqa: E501
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Set the start_time of this ShardGroupManifest.

        :param start_time: The start_time of this ShardGroupManifest.
        :type: datetime
        """  # noqa: E501
        if start_time is None:
            raise ValueError("Invalid value for `start_time`, must not be `None`")  # noqa: E501
        self._start_time = start_time

    @property
    def end_time(self):
        """Get the end_time of this ShardGroupManifest.

        :return: The end_time of this ShardGroupManifest.
        :rtype: datetime
        """  # noqa: E501
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Set the end_time of this ShardGroupManifest.

        :param end_time: The end_time of this ShardGroupManifest.
        :type: datetime
        """  # noqa: E501
        if end_time is None:
            raise ValueError("Invalid value for `end_time`, must not be `None`")  # noqa: E501
        self._end_time = end_time

    @property
    def deleted_at(self):
        """Get the deleted_at of this ShardGroupManifest.

        :return: The deleted_at of this ShardGroupManifest.
        :rtype: datetime
        """  # noqa: E501
        return self._deleted_at

    @deleted_at.setter
    def deleted_at(self, deleted_at):
        """Set the deleted_at of this ShardGroupManifest.

        :param deleted_at: The deleted_at of this ShardGroupManifest.
        :type: datetime
        """  # noqa: E501
        self._deleted_at = deleted_at

    @property
    def truncated_at(self):
        """Get the truncated_at of this ShardGroupManifest.

        :return: The truncated_at of this ShardGroupManifest.
        :rtype: datetime
        """  # noqa: E501
        return self._truncated_at

    @truncated_at.setter
    def truncated_at(self, truncated_at):
        """Set the truncated_at of this ShardGroupManifest.

        :param truncated_at: The truncated_at of this ShardGroupManifest.
        :type: datetime
        """  # noqa: E501
        self._truncated_at = truncated_at

    @property
    def shards(self):
        """Get the shards of this ShardGroupManifest.

        :return: The shards of this ShardGroupManifest.
        :rtype: list[ShardManifest]
        """  # noqa: E501
        return self._shards

    @shards.setter
    def shards(self, shards):
        """Set the shards of this ShardGroupManifest.

        :param shards: The shards of this ShardGroupManifest.
        :type: list[ShardManifest]
        """  # noqa: E501
        if shards is None:
            raise ValueError("Invalid value for `shards`, must not be `None`")  # noqa: E501
        self._shards = shards

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, ShardGroupManifest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other
